# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class V1betaintegrationsintegrationIdUuidIntegration(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'object',
        'workspace_id': 'RimeUUID',
        'creation_time': 'datetime',
        'name': 'str',
        'type': 'IntegrationIntegrationType',
        'schema': 'IntegrationIntegrationSchema',
        'level': 'IntegrationIntegrationLevel'
    }

    attribute_map = {
        'id': 'id',
        'workspace_id': 'workspaceId',
        'creation_time': 'creationTime',
        'name': 'name',
        'type': 'type',
        'schema': 'schema',
        'level': 'level'
    }

    def __init__(self, id=None, workspace_id=None, creation_time=None, name=None, type=None, schema=None, level=None):  # noqa: E501
        """V1betaintegrationsintegrationIdUuidIntegration - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._workspace_id = None
        self._creation_time = None
        self._name = None
        self._type = None
        self._schema = None
        self._level = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if workspace_id is not None:
            self.workspace_id = workspace_id
        if creation_time is not None:
            self.creation_time = creation_time
        if name is not None:
            self.name = name
        if type is not None:
            self.type = type
        if schema is not None:
            self.schema = schema
        if level is not None:
            self.level = level

    @property
    def id(self):
        """Gets the id of this V1betaintegrationsintegrationIdUuidIntegration.  # noqa: E501

        Unique ID of an object in RIME.  # noqa: E501

        :return: The id of this V1betaintegrationsintegrationIdUuidIntegration.  # noqa: E501
        :rtype: object
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this V1betaintegrationsintegrationIdUuidIntegration.

        Unique ID of an object in RIME.  # noqa: E501

        :param id: The id of this V1betaintegrationsintegrationIdUuidIntegration.  # noqa: E501
        :type: object
        """

        self._id = id

    @property
    def workspace_id(self):
        """Gets the workspace_id of this V1betaintegrationsintegrationIdUuidIntegration.  # noqa: E501


        :return: The workspace_id of this V1betaintegrationsintegrationIdUuidIntegration.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._workspace_id

    @workspace_id.setter
    def workspace_id(self, workspace_id):
        """Sets the workspace_id of this V1betaintegrationsintegrationIdUuidIntegration.


        :param workspace_id: The workspace_id of this V1betaintegrationsintegrationIdUuidIntegration.  # noqa: E501
        :type: RimeUUID
        """

        self._workspace_id = workspace_id

    @property
    def creation_time(self):
        """Gets the creation_time of this V1betaintegrationsintegrationIdUuidIntegration.  # noqa: E501


        :return: The creation_time of this V1betaintegrationsintegrationIdUuidIntegration.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """Sets the creation_time of this V1betaintegrationsintegrationIdUuidIntegration.


        :param creation_time: The creation_time of this V1betaintegrationsintegrationIdUuidIntegration.  # noqa: E501
        :type: datetime
        """

        self._creation_time = creation_time

    @property
    def name(self):
        """Gets the name of this V1betaintegrationsintegrationIdUuidIntegration.  # noqa: E501


        :return: The name of this V1betaintegrationsintegrationIdUuidIntegration.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this V1betaintegrationsintegrationIdUuidIntegration.


        :param name: The name of this V1betaintegrationsintegrationIdUuidIntegration.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def type(self):
        """Gets the type of this V1betaintegrationsintegrationIdUuidIntegration.  # noqa: E501


        :return: The type of this V1betaintegrationsintegrationIdUuidIntegration.  # noqa: E501
        :rtype: IntegrationIntegrationType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this V1betaintegrationsintegrationIdUuidIntegration.


        :param type: The type of this V1betaintegrationsintegrationIdUuidIntegration.  # noqa: E501
        :type: IntegrationIntegrationType
        """

        self._type = type

    @property
    def schema(self):
        """Gets the schema of this V1betaintegrationsintegrationIdUuidIntegration.  # noqa: E501


        :return: The schema of this V1betaintegrationsintegrationIdUuidIntegration.  # noqa: E501
        :rtype: IntegrationIntegrationSchema
        """
        return self._schema

    @schema.setter
    def schema(self, schema):
        """Sets the schema of this V1betaintegrationsintegrationIdUuidIntegration.


        :param schema: The schema of this V1betaintegrationsintegrationIdUuidIntegration.  # noqa: E501
        :type: IntegrationIntegrationSchema
        """

        self._schema = schema

    @property
    def level(self):
        """Gets the level of this V1betaintegrationsintegrationIdUuidIntegration.  # noqa: E501


        :return: The level of this V1betaintegrationsintegrationIdUuidIntegration.  # noqa: E501
        :rtype: IntegrationIntegrationLevel
        """
        return self._level

    @level.setter
    def level(self, level):
        """Sets the level of this V1betaintegrationsintegrationIdUuidIntegration.


        :param level: The level of this V1betaintegrationsintegrationIdUuidIntegration.  # noqa: E501
        :type: IntegrationIntegrationLevel
        """

        self._level = level

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1betaintegrationsintegrationIdUuidIntegration, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1betaintegrationsintegrationIdUuidIntegration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from rime_sdk.swagger.swagger_client.api_client import ApiClient


class FileUploadApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def file_upload_delete_uploaded_file_url(self, uploaded_url, **kwargs):  # noqa: E501
        """DeleteUploadedFileURL  # noqa: E501

        Deletes the uploaded dataset at the specified URL from the blob store.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.file_upload_delete_uploaded_file_url(uploaded_url, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uploaded_url: URL of the uploaded file to delete. (required)
        :return: RimeDeleteUploadedFileURLResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.file_upload_delete_uploaded_file_url_with_http_info(uploaded_url, **kwargs)  # noqa: E501
        else:
            (data) = self.file_upload_delete_uploaded_file_url_with_http_info(uploaded_url, **kwargs)  # noqa: E501
            return data

    def file_upload_delete_uploaded_file_url_with_http_info(self, uploaded_url, **kwargs):  # noqa: E501
        """DeleteUploadedFileURL  # noqa: E501

        Deletes the uploaded dataset at the specified URL from the blob store.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.file_upload_delete_uploaded_file_url_with_http_info(uploaded_url, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uploaded_url: URL of the uploaded file to delete. (required)
        :return: RimeDeleteUploadedFileURLResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uploaded_url']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method file_upload_delete_uploaded_file_url" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uploaded_url' is set
        if ('uploaded_url' not in params or
                params['uploaded_url'] is None):
            raise ValueError("Missing the required parameter `uploaded_url` when calling `file_upload_delete_uploaded_file_url`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'uploaded_url' in params:
            query_params.append(('uploadedUrl', params['uploaded_url']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/datasets/upload-url', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeDeleteUploadedFileURLResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def file_upload_get_dataset_file_upload_url(self, file_name, **kwargs):  # noqa: E501
        """GetDatasetFileUploadURL  # noqa: E501

        Returns a pre-signed upload URL for a dataset.  File uploading is not currently supported in a Cloud deployment. Please use an external data source instead.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.file_upload_get_dataset_file_upload_url(file_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_name: Path of dataset file on the local file system. (required)
        :param str upload_path: Specify a path in the blob store to use for data uploads.
        :return: RimeGetDatasetFileUploadURLResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.file_upload_get_dataset_file_upload_url_with_http_info(file_name, **kwargs)  # noqa: E501
        else:
            (data) = self.file_upload_get_dataset_file_upload_url_with_http_info(file_name, **kwargs)  # noqa: E501
            return data

    def file_upload_get_dataset_file_upload_url_with_http_info(self, file_name, **kwargs):  # noqa: E501
        """GetDatasetFileUploadURL  # noqa: E501

        Returns a pre-signed upload URL for a dataset.  File uploading is not currently supported in a Cloud deployment. Please use an external data source instead.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.file_upload_get_dataset_file_upload_url_with_http_info(file_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_name: Path of dataset file on the local file system. (required)
        :param str upload_path: Specify a path in the blob store to use for data uploads.
        :return: RimeGetDatasetFileUploadURLResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['file_name', 'upload_path']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method file_upload_get_dataset_file_upload_url" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'file_name' is set
        if ('file_name' not in params or
                params['file_name'] is None):
            raise ValueError("Missing the required parameter `file_name` when calling `file_upload_get_dataset_file_upload_url`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'file_name' in params:
            query_params.append(('fileName', params['file_name']))  # noqa: E501
        if 'upload_path' in params:
            query_params.append(('uploadPath', params['upload_path']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/datasets/upload-url', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeGetDatasetFileUploadURLResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def file_upload_get_dataset_file_upload_url2(self, body, **kwargs):  # noqa: E501
        """GetDatasetFileUploadURL  # noqa: E501

        Returns a pre-signed upload URL for a dataset.  File uploading is not currently supported in a Cloud deployment. Please use an external data source instead.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.file_upload_get_dataset_file_upload_url2(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RimeGetDatasetFileUploadURLRequest body: (required)
        :return: RimeGetDatasetFileUploadURLResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.file_upload_get_dataset_file_upload_url2_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.file_upload_get_dataset_file_upload_url2_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def file_upload_get_dataset_file_upload_url2_with_http_info(self, body, **kwargs):  # noqa: E501
        """GetDatasetFileUploadURL  # noqa: E501

        Returns a pre-signed upload URL for a dataset.  File uploading is not currently supported in a Cloud deployment. Please use an external data source instead.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.file_upload_get_dataset_file_upload_url2_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RimeGetDatasetFileUploadURLRequest body: (required)
        :return: RimeGetDatasetFileUploadURLResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method file_upload_get_dataset_file_upload_url2" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `file_upload_get_dataset_file_upload_url2`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/datasets/upload-url', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeGetDatasetFileUploadURLResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def file_upload_get_model_directory_upload_urls(self, directory_name, relative_file_paths, **kwargs):  # noqa: E501
        """GetModelDirectoryUploadURL  # noqa: E501

        Returns a pre-signed upload URL for a model directory.  File uploading is not currently supported in a Cloud deployment. Please use an external data source instead.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.file_upload_get_model_directory_upload_urls(directory_name, relative_file_paths, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str directory_name: Path of model directory on local file system. (required)
        :param list[str] relative_file_paths: Array of relative paths from the model directory to model files. (required)
        :param str upload_path: Specify a path in the blob store to which the model will be uploaded.
        :return: RimeGetModelDirectoryUploadURLsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.file_upload_get_model_directory_upload_urls_with_http_info(directory_name, relative_file_paths, **kwargs)  # noqa: E501
        else:
            (data) = self.file_upload_get_model_directory_upload_urls_with_http_info(directory_name, relative_file_paths, **kwargs)  # noqa: E501
            return data

    def file_upload_get_model_directory_upload_urls_with_http_info(self, directory_name, relative_file_paths, **kwargs):  # noqa: E501
        """GetModelDirectoryUploadURL  # noqa: E501

        Returns a pre-signed upload URL for a model directory.  File uploading is not currently supported in a Cloud deployment. Please use an external data source instead.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.file_upload_get_model_directory_upload_urls_with_http_info(directory_name, relative_file_paths, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str directory_name: Path of model directory on local file system. (required)
        :param list[str] relative_file_paths: Array of relative paths from the model directory to model files. (required)
        :param str upload_path: Specify a path in the blob store to which the model will be uploaded.
        :return: RimeGetModelDirectoryUploadURLsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['directory_name', 'relative_file_paths', 'upload_path']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method file_upload_get_model_directory_upload_urls" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'directory_name' is set
        if ('directory_name' not in params or
                params['directory_name'] is None):
            raise ValueError("Missing the required parameter `directory_name` when calling `file_upload_get_model_directory_upload_urls`")  # noqa: E501
        # verify the required parameter 'relative_file_paths' is set
        if ('relative_file_paths' not in params or
                params['relative_file_paths'] is None):
            raise ValueError("Missing the required parameter `relative_file_paths` when calling `file_upload_get_model_directory_upload_urls`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'directory_name' in params:
            query_params.append(('directoryName', params['directory_name']))  # noqa: E501
        if 'relative_file_paths' in params:
            query_params.append(('relativeFilePaths', params['relative_file_paths']))  # noqa: E501
            collection_formats['relativeFilePaths'] = 'multi'  # noqa: E501
        if 'upload_path' in params:
            query_params.append(('uploadPath', params['upload_path']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/models/upload-url', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeGetModelDirectoryUploadURLsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def file_upload_get_model_directory_upload_urls2(self, body, **kwargs):  # noqa: E501
        """GetModelDirectoryUploadURL  # noqa: E501

        Returns a pre-signed upload URL for a model directory.  File uploading is not currently supported in a Cloud deployment. Please use an external data source instead.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.file_upload_get_model_directory_upload_urls2(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RimeGetModelDirectoryUploadURLsRequest body: (required)
        :return: RimeGetModelDirectoryUploadURLsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.file_upload_get_model_directory_upload_urls2_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.file_upload_get_model_directory_upload_urls2_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def file_upload_get_model_directory_upload_urls2_with_http_info(self, body, **kwargs):  # noqa: E501
        """GetModelDirectoryUploadURL  # noqa: E501

        Returns a pre-signed upload URL for a model directory.  File uploading is not currently supported in a Cloud deployment. Please use an external data source instead.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.file_upload_get_model_directory_upload_urls2_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RimeGetModelDirectoryUploadURLsRequest body: (required)
        :return: RimeGetModelDirectoryUploadURLsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method file_upload_get_model_directory_upload_urls2" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `file_upload_get_model_directory_upload_urls2`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/models/upload-url', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeGetModelDirectoryUploadURLsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def file_upload_list_uploaded_file_urls(self, **kwargs):  # noqa: E501
        """ListUploadedFileURLs  # noqa: E501

        List all blob store URLs for uploaded files.  File uploading is not currently supported in a Cloud deployment. Please use an external data source instead.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.file_upload_list_uploaded_file_urls(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: RimeListUploadedFileURLsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.file_upload_list_uploaded_file_urls_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.file_upload_list_uploaded_file_urls_with_http_info(**kwargs)  # noqa: E501
            return data

    def file_upload_list_uploaded_file_urls_with_http_info(self, **kwargs):  # noqa: E501
        """ListUploadedFileURLs  # noqa: E501

        List all blob store URLs for uploaded files.  File uploading is not currently supported in a Cloud deployment. Please use an external data source instead.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.file_upload_list_uploaded_file_urls_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: RimeListUploadedFileURLsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method file_upload_list_uploaded_file_urls" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/uploaded-file-urls', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeListUploadedFileURLsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from rime_sdk.swagger.swagger_client.api_client import ApiClient


class GenerativeModelTestingApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def results(self, job_id_uuid, **kwargs):  # noqa: E501
        """GetGenerativeModelTestResults  # noqa: E501

        Retrieve the results of a generative model testing for a successful job. This is a paginated API.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.results(job_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str job_id_uuid: Unique object ID. (required)
        :param str page_token: A token representing one page from the list returned by a GetGenerativeModelTestResults API. The GetGenerativeModelTestResults API returns a page_token when there is more than one page of results.
        :param str page_size: The maximum number of objects to return in a single page.  Maximum page size is 1000.
        :return: GenerativetestingGetGenerativeModelTestResultsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.results_with_http_info(job_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.results_with_http_info(job_id_uuid, **kwargs)  # noqa: E501
            return data

    def results_with_http_info(self, job_id_uuid, **kwargs):  # noqa: E501
        """GetGenerativeModelTestResults  # noqa: E501

        Retrieve the results of a generative model testing for a successful job. This is a paginated API.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.results_with_http_info(job_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str job_id_uuid: Unique object ID. (required)
        :param str page_token: A token representing one page from the list returned by a GetGenerativeModelTestResults API. The GetGenerativeModelTestResults API returns a page_token when there is more than one page of results.
        :param str page_size: The maximum number of objects to return in a single page.  Maximum page size is 1000.
        :return: GenerativetestingGetGenerativeModelTestResultsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['job_id_uuid', 'page_token', 'page_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method results" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'job_id_uuid' is set
        if ('job_id_uuid' not in params or
                params['job_id_uuid'] is None):
            raise ValueError("Missing the required parameter `job_id_uuid` when calling `results`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'job_id_uuid' in params:
            path_params['jobId.uuid'] = params['job_id_uuid']  # noqa: E501

        query_params = []
        if 'page_token' in params:
            query_params.append(('pageToken', params['page_token']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/generative/testing/{jobId.uuid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GenerativetestingGetGenerativeModelTestResultsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def start_generative_test(self, body, **kwargs):  # noqa: E501
        """StartGenerativeModelTest  # noqa: E501

        Starts a generative model test on the specified GAI model with default prompt bank. The status of the job can be tracked through the JobReader service. The results can of the test can be retrieved using the GetGenerativeModelTestResults API.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_generative_test(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param GenerativetestingStartGenerativeModelTestRequest body: (required)
        :return: GenerativetestingStartGenerativeModelTestResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.start_generative_test_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.start_generative_test_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def start_generative_test_with_http_info(self, body, **kwargs):  # noqa: E501
        """StartGenerativeModelTest  # noqa: E501

        Starts a generative model test on the specified GAI model with default prompt bank. The status of the job can be tracked through the JobReader service. The results can of the test can be retrieved using the GetGenerativeModelTestResults API.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_generative_test_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param GenerativetestingStartGenerativeModelTestRequest body: (required)
        :return: GenerativetestingStartGenerativeModelTestResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_generative_test" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `start_generative_test`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/generative/testing', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GenerativetestingStartGenerativeModelTestResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def start_generative_test_simple(self, body, **kwargs):  # noqa: E501
        """StartGenerativeModelTestSimple  # noqa: E501

        Starts a generative model test on the specified GAI model with simple prompt bank.  This is only meant to be used to test your setup and connections, results should not be seen as complete nor actionable. The status of the job can be tracked through the JobReader service. The results can of the test can be retrieved using the GetGenerativeModelTestResults API.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_generative_test_simple(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param GenerativetestingStartGenerativeModelTestRequest body: (required)
        :return: GenerativetestingStartGenerativeModelTestResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.start_generative_test_simple_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.start_generative_test_simple_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def start_generative_test_simple_with_http_info(self, body, **kwargs):  # noqa: E501
        """StartGenerativeModelTestSimple  # noqa: E501

        Starts a generative model test on the specified GAI model with simple prompt bank.  This is only meant to be used to test your setup and connections, results should not be seen as complete nor actionable. The status of the job can be tracked through the JobReader service. The results can of the test can be retrieved using the GetGenerativeModelTestResults API.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_generative_test_simple_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param GenerativetestingStartGenerativeModelTestRequest body: (required)
        :return: GenerativetestingStartGenerativeModelTestResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_generative_test_simple" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `start_generative_test_simple`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/generative/testing/simple', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GenerativetestingStartGenerativeModelTestResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RimeGetDatasetFileUploadURLRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'file_name': 'str',
        'upload_path': 'str'
    }

    attribute_map = {
        'file_name': 'fileName',
        'upload_path': 'uploadPath'
    }

    def __init__(self, file_name=None, upload_path=None):  # noqa: E501
        """RimeGetDatasetFileUploadURLRequest - a model defined in Swagger"""  # noqa: E501
        self._file_name = None
        self._upload_path = None
        self.discriminator = None
        self.file_name = file_name
        if upload_path is not None:
            self.upload_path = upload_path

    @property
    def file_name(self):
        """Gets the file_name of this RimeGetDatasetFileUploadURLRequest.  # noqa: E501

        Path of dataset file on the local file system.  # noqa: E501

        :return: The file_name of this RimeGetDatasetFileUploadURLRequest.  # noqa: E501
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this RimeGetDatasetFileUploadURLRequest.

        Path of dataset file on the local file system.  # noqa: E501

        :param file_name: The file_name of this RimeGetDatasetFileUploadURLRequest.  # noqa: E501
        :type: str
        """
        if file_name is None:
            raise ValueError("Invalid value for `file_name`, must not be `None`")  # noqa: E501

        self._file_name = file_name

    @property
    def upload_path(self):
        """Gets the upload_path of this RimeGetDatasetFileUploadURLRequest.  # noqa: E501

        Specify a path in the blob store to use for data uploads.  # noqa: E501

        :return: The upload_path of this RimeGetDatasetFileUploadURLRequest.  # noqa: E501
        :rtype: str
        """
        return self._upload_path

    @upload_path.setter
    def upload_path(self, upload_path):
        """Sets the upload_path of this RimeGetDatasetFileUploadURLRequest.

        Specify a path in the blob store to use for data uploads.  # noqa: E501

        :param upload_path: The upload_path of this RimeGetDatasetFileUploadURLRequest.  # noqa: E501
        :type: str
        """

        self._upload_path = upload_path

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RimeGetDatasetFileUploadURLRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RimeGetDatasetFileUploadURLRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TestrunresultTestFeatureResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'url_safe_feature_id': 'str',
        'feature_name': 'str',
        'feature_type': 'RimeFeatureType',
        'severity': 'RimeSeverity',
        'summary_counts': 'TestrunresultResultSummaryCounts',
        'failing_tests': 'list[str]',
        'num_failing_rows': 'str',
        'failing_rows_html': 'str',
        'drift_statistic': 'RimeNamedDouble',
        'model_impact': 'RimeNamedDouble',
        'feature_infos': 'list[str]',
        'display': 'TestrunresultTestFeatureResultDisplay'
    }

    attribute_map = {
        'url_safe_feature_id': 'urlSafeFeatureId',
        'feature_name': 'featureName',
        'feature_type': 'featureType',
        'severity': 'severity',
        'summary_counts': 'summaryCounts',
        'failing_tests': 'failingTests',
        'num_failing_rows': 'numFailingRows',
        'failing_rows_html': 'failingRowsHtml',
        'drift_statistic': 'driftStatistic',
        'model_impact': 'modelImpact',
        'feature_infos': 'featureInfos',
        'display': 'display'
    }

    def __init__(self, url_safe_feature_id=None, feature_name=None, feature_type=None, severity=None, summary_counts=None, failing_tests=None, num_failing_rows=None, failing_rows_html=None, drift_statistic=None, model_impact=None, feature_infos=None, display=None):  # noqa: E501
        """TestrunresultTestFeatureResult - a model defined in Swagger"""  # noqa: E501
        self._url_safe_feature_id = None
        self._feature_name = None
        self._feature_type = None
        self._severity = None
        self._summary_counts = None
        self._failing_tests = None
        self._num_failing_rows = None
        self._failing_rows_html = None
        self._drift_statistic = None
        self._model_impact = None
        self._feature_infos = None
        self._display = None
        self.discriminator = None
        if url_safe_feature_id is not None:
            self.url_safe_feature_id = url_safe_feature_id
        if feature_name is not None:
            self.feature_name = feature_name
        if feature_type is not None:
            self.feature_type = feature_type
        if severity is not None:
            self.severity = severity
        if summary_counts is not None:
            self.summary_counts = summary_counts
        if failing_tests is not None:
            self.failing_tests = failing_tests
        if num_failing_rows is not None:
            self.num_failing_rows = num_failing_rows
        if failing_rows_html is not None:
            self.failing_rows_html = failing_rows_html
        if drift_statistic is not None:
            self.drift_statistic = drift_statistic
        if model_impact is not None:
            self.model_impact = model_impact
        if feature_infos is not None:
            self.feature_infos = feature_infos
        if display is not None:
            self.display = display

    @property
    def url_safe_feature_id(self):
        """Gets the url_safe_feature_id of this TestrunresultTestFeatureResult.  # noqa: E501

        The URL-compatible (base 64) encoding of feature name.  # noqa: E501

        :return: The url_safe_feature_id of this TestrunresultTestFeatureResult.  # noqa: E501
        :rtype: str
        """
        return self._url_safe_feature_id

    @url_safe_feature_id.setter
    def url_safe_feature_id(self, url_safe_feature_id):
        """Sets the url_safe_feature_id of this TestrunresultTestFeatureResult.

        The URL-compatible (base 64) encoding of feature name.  # noqa: E501

        :param url_safe_feature_id: The url_safe_feature_id of this TestrunresultTestFeatureResult.  # noqa: E501
        :type: str
        """

        self._url_safe_feature_id = url_safe_feature_id

    @property
    def feature_name(self):
        """Gets the feature_name of this TestrunresultTestFeatureResult.  # noqa: E501

        The human-readable feature name.  # noqa: E501

        :return: The feature_name of this TestrunresultTestFeatureResult.  # noqa: E501
        :rtype: str
        """
        return self._feature_name

    @feature_name.setter
    def feature_name(self, feature_name):
        """Sets the feature_name of this TestrunresultTestFeatureResult.

        The human-readable feature name.  # noqa: E501

        :param feature_name: The feature_name of this TestrunresultTestFeatureResult.  # noqa: E501
        :type: str
        """

        self._feature_name = feature_name

    @property
    def feature_type(self):
        """Gets the feature_type of this TestrunresultTestFeatureResult.  # noqa: E501


        :return: The feature_type of this TestrunresultTestFeatureResult.  # noqa: E501
        :rtype: RimeFeatureType
        """
        return self._feature_type

    @feature_type.setter
    def feature_type(self, feature_type):
        """Sets the feature_type of this TestrunresultTestFeatureResult.


        :param feature_type: The feature_type of this TestrunresultTestFeatureResult.  # noqa: E501
        :type: RimeFeatureType
        """

        self._feature_type = feature_type

    @property
    def severity(self):
        """Gets the severity of this TestrunresultTestFeatureResult.  # noqa: E501


        :return: The severity of this TestrunresultTestFeatureResult.  # noqa: E501
        :rtype: RimeSeverity
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """Sets the severity of this TestrunresultTestFeatureResult.


        :param severity: The severity of this TestrunresultTestFeatureResult.  # noqa: E501
        :type: RimeSeverity
        """

        self._severity = severity

    @property
    def summary_counts(self):
        """Gets the summary_counts of this TestrunresultTestFeatureResult.  # noqa: E501


        :return: The summary_counts of this TestrunresultTestFeatureResult.  # noqa: E501
        :rtype: TestrunresultResultSummaryCounts
        """
        return self._summary_counts

    @summary_counts.setter
    def summary_counts(self, summary_counts):
        """Sets the summary_counts of this TestrunresultTestFeatureResult.


        :param summary_counts: The summary_counts of this TestrunresultTestFeatureResult.  # noqa: E501
        :type: TestrunresultResultSummaryCounts
        """

        self._summary_counts = summary_counts

    @property
    def failing_tests(self):
        """Gets the failing_tests of this TestrunresultTestFeatureResult.  # noqa: E501

        The list of tests that fail for the feature.  # noqa: E501

        :return: The failing_tests of this TestrunresultTestFeatureResult.  # noqa: E501
        :rtype: list[str]
        """
        return self._failing_tests

    @failing_tests.setter
    def failing_tests(self, failing_tests):
        """Sets the failing_tests of this TestrunresultTestFeatureResult.

        The list of tests that fail for the feature.  # noqa: E501

        :param failing_tests: The failing_tests of this TestrunresultTestFeatureResult.  # noqa: E501
        :type: list[str]
        """

        self._failing_tests = failing_tests

    @property
    def num_failing_rows(self):
        """Gets the num_failing_rows of this TestrunresultTestFeatureResult.  # noqa: E501

        The number of rows that fail.  # noqa: E501

        :return: The num_failing_rows of this TestrunresultTestFeatureResult.  # noqa: E501
        :rtype: str
        """
        return self._num_failing_rows

    @num_failing_rows.setter
    def num_failing_rows(self, num_failing_rows):
        """Sets the num_failing_rows of this TestrunresultTestFeatureResult.

        The number of rows that fail.  # noqa: E501

        :param num_failing_rows: The num_failing_rows of this TestrunresultTestFeatureResult.  # noqa: E501
        :type: str
        """

        self._num_failing_rows = num_failing_rows

    @property
    def failing_rows_html(self):
        """Gets the failing_rows_html of this TestrunresultTestFeatureResult.  # noqa: E501

        The names of the rows that fail; may contain HTML.  # noqa: E501

        :return: The failing_rows_html of this TestrunresultTestFeatureResult.  # noqa: E501
        :rtype: str
        """
        return self._failing_rows_html

    @failing_rows_html.setter
    def failing_rows_html(self, failing_rows_html):
        """Sets the failing_rows_html of this TestrunresultTestFeatureResult.

        The names of the rows that fail; may contain HTML.  # noqa: E501

        :param failing_rows_html: The failing_rows_html of this TestrunresultTestFeatureResult.  # noqa: E501
        :type: str
        """

        self._failing_rows_html = failing_rows_html

    @property
    def drift_statistic(self):
        """Gets the drift_statistic of this TestrunresultTestFeatureResult.  # noqa: E501


        :return: The drift_statistic of this TestrunresultTestFeatureResult.  # noqa: E501
        :rtype: RimeNamedDouble
        """
        return self._drift_statistic

    @drift_statistic.setter
    def drift_statistic(self, drift_statistic):
        """Sets the drift_statistic of this TestrunresultTestFeatureResult.


        :param drift_statistic: The drift_statistic of this TestrunresultTestFeatureResult.  # noqa: E501
        :type: RimeNamedDouble
        """

        self._drift_statistic = drift_statistic

    @property
    def model_impact(self):
        """Gets the model_impact of this TestrunresultTestFeatureResult.  # noqa: E501


        :return: The model_impact of this TestrunresultTestFeatureResult.  # noqa: E501
        :rtype: RimeNamedDouble
        """
        return self._model_impact

    @model_impact.setter
    def model_impact(self, model_impact):
        """Sets the model_impact of this TestrunresultTestFeatureResult.


        :param model_impact: The model_impact of this TestrunresultTestFeatureResult.  # noqa: E501
        :type: RimeNamedDouble
        """

        self._model_impact = model_impact

    @property
    def feature_infos(self):
        """Gets the feature_infos of this TestrunresultTestFeatureResult.  # noqa: E501

        The list of feature information used.  # noqa: E501

        :return: The feature_infos of this TestrunresultTestFeatureResult.  # noqa: E501
        :rtype: list[str]
        """
        return self._feature_infos

    @feature_infos.setter
    def feature_infos(self, feature_infos):
        """Sets the feature_infos of this TestrunresultTestFeatureResult.

        The list of feature information used.  # noqa: E501

        :param feature_infos: The feature_infos of this TestrunresultTestFeatureResult.  # noqa: E501
        :type: list[str]
        """

        self._feature_infos = feature_infos

    @property
    def display(self):
        """Gets the display of this TestrunresultTestFeatureResult.  # noqa: E501


        :return: The display of this TestrunresultTestFeatureResult.  # noqa: E501
        :rtype: TestrunresultTestFeatureResultDisplay
        """
        return self._display

    @display.setter
    def display(self, display):
        """Sets the display of this TestrunresultTestFeatureResult.


        :param display: The display of this TestrunresultTestFeatureResult.  # noqa: E501
        :type: TestrunresultTestFeatureResultDisplay
        """

        self._display = display

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TestrunresultTestFeatureResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TestrunresultTestFeatureResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



"""Library defining the interface to Image Builder jobs."""

import time
from typing import Any, Dict, List, Optional

from rime_sdk.internal.rest_error_handler import RESTErrorHandler
from rime_sdk.swagger.swagger_client import ApiClient, ImageRegistryApi
from rime_sdk.swagger.swagger_client.models import (
    ManagedImagePackageRequirement,
    ManagedImagePipRequirement,
    RimeManagedImage,
    RimeManagedImageStatus,
)


class ImageBuilder:
    """An interface to an Image Builder object."""

    def __init__(
        self,
        api_client: ApiClient,
        name: str,
        requirements: Optional[List[ManagedImagePipRequirement]] = None,
        package_requirements: Optional[List[ManagedImagePackageRequirement]] = None,
        python_version: Optional[str] = None,
    ) -> None:
        """Create a new Image Builder.

        Args:
            api_client: ApiClient
                The client used to query about the status of the Job.
            name: str
                The name of the Managed Image that this object monitors.
            requirements: Optional[List[ManagedImage.PipRequirement]] = None
                Optional list of pip requirements to be installed on this Image.
            package_requirements: Optional[List[ManagedImage.PackageRequirement]] = None
                Optional list of system package requirements to be installed on
                this Image.
            python_version: Optional[str]
                An optional version string specifying only the major and minor version
                for the python interpreter used. The string should be of the format
                X.Y and be present in the set of supported versions.
        """

        self._api_client = api_client
        self._name = name
        self._requirements = requirements
        self._package_requirements = package_requirements
        self._python_version = python_version

    def __eq__(self, obj: Any) -> bool:
        """Check if this builder is equivalent to 'obj'."""
        return isinstance(obj, ImageBuilder) and self._name == obj._name

    def __str__(self) -> str:
        """Pretty-print the object."""
        ret = {"name": self._name}
        if self._requirements:
            ret["requirements"] = str(
                [f"{req.name}{req.version_specifier}" for req in self._requirements]
            )
        if self._package_requirements:
            ret["package_requirements"] = str(
                [
                    f"{req.name}{req.version_specifier}"
                    for req in self._package_requirements
                ]
            )
        if self._python_version:
            ret["python_version"] = self._python_version
        return f"ImageBuilder {ret}"

    def get_status(
        self,
        verbose: bool = True,
        wait_until_finish: bool = False,
        poll_rate_sec: float = 5.0,
    ) -> Dict:
        """Return the status of the Image Build Job.

        This method includes a toggle to wait until the Image Build job
        finishes.

        Arguments:
            verbose: bool
                Specifies whether to print diagnostic information such as logs.
                By default, this value is set to True.
            wait_until_finish: bool
                Specifies whether to block until the Image is READY or FAILED.
                By default, this value is set to False.
            poll_rate_sec: float
                The frequency with which to poll the Image's build status.
                By default, this value is set to 5 seconds.

        Returns:
            Dict:
                A dictionary representing the Image's state.
        """
        # Create backend client stubs to use for the remainder of this session.
        image = RimeManagedImage(status=RimeManagedImageStatus.UNSPECIFIED)
        if verbose:
            print(f"Querying for Managed Image '{self._name}':")
        # Do not repeat if the job is finished or blocking is disabled.
        repeat = True
        poll_count = 0
        api = ImageRegistryApi(self._api_client)
        while repeat and image.status not in (
            RimeManagedImageStatus.FAILED,
            RimeManagedImageStatus.OUTDATED,
            RimeManagedImageStatus.READY,
        ):
            with RESTErrorHandler():
                image = api.image_registry_get_image(name=self._name).image
            if verbose:
                status_name = image.status
                print(
                    f"\rStatus: {status_name}, Poll Count: {poll_count}",
                    end="",
                )
            if wait_until_finish:
                time.sleep(poll_rate_sec)
            else:
                repeat = False
            poll_count += 1

            # TODO(VAL-2433): Add ability to get and print logging information from a
            # failed build.

        return image.to_dict()



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from rime_sdk.swagger.swagger_client.api_client import ApiClient


class FeatureFlagApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def feature_flag_get_enabled_feature(self, customer_name, feature, **kwargs):  # noqa: E501
        """GetEnabledFeature  # noqa: E501

        Returns whether a feature is enabled in license for a customer.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.feature_flag_get_enabled_feature(customer_name, feature, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str customer_name: Name of the customer to query. (required)
        :param str feature: The feature to check. (required)
        :return: RimeGetEnabledFeatureResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.feature_flag_get_enabled_feature_with_http_info(customer_name, feature, **kwargs)  # noqa: E501
        else:
            (data) = self.feature_flag_get_enabled_feature_with_http_info(customer_name, feature, **kwargs)  # noqa: E501
            return data

    def feature_flag_get_enabled_feature_with_http_info(self, customer_name, feature, **kwargs):  # noqa: E501
        """GetEnabledFeature  # noqa: E501

        Returns whether a feature is enabled in license for a customer.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.feature_flag_get_enabled_feature_with_http_info(customer_name, feature, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str customer_name: Name of the customer to query. (required)
        :param str feature: The feature to check. (required)
        :return: RimeGetEnabledFeatureResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['customer_name', 'feature']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method feature_flag_get_enabled_feature" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'customer_name' is set
        if ('customer_name' not in params or
                params['customer_name'] is None):
            raise ValueError("Missing the required parameter `customer_name` when calling `feature_flag_get_enabled_feature`")  # noqa: E501
        # verify the required parameter 'feature' is set
        if ('feature' not in params or
                params['feature'] is None):
            raise ValueError("Missing the required parameter `feature` when calling `feature_flag_get_enabled_feature`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'customer_name' in params:
            path_params['customerName'] = params['customer_name']  # noqa: E501
        if 'feature' in params:
            path_params['feature'] = params['feature']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/feature-flags/{customerName}/features/{feature}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeGetEnabledFeatureResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def feature_flag_get_feature_flag(self, customer_name, **kwargs):  # noqa: E501
        """GetFeatureFlag  # noqa: E501

        Returns feature message with customer name This endpoint is deprecated, use `ListEnabledFeatures` or `GetLimitStatusRequest` instead.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.feature_flag_get_feature_flag(customer_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str customer_name: The customer to retrieve feature flags for. (required)
        :return: RimeGetFeatureFlagsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.feature_flag_get_feature_flag_with_http_info(customer_name, **kwargs)  # noqa: E501
        else:
            (data) = self.feature_flag_get_feature_flag_with_http_info(customer_name, **kwargs)  # noqa: E501
            return data

    def feature_flag_get_feature_flag_with_http_info(self, customer_name, **kwargs):  # noqa: E501
        """GetFeatureFlag  # noqa: E501

        Returns feature message with customer name This endpoint is deprecated, use `ListEnabledFeatures` or `GetLimitStatusRequest` instead.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.feature_flag_get_feature_flag_with_http_info(customer_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str customer_name: The customer to retrieve feature flags for. (required)
        :return: RimeGetFeatureFlagsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['customer_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method feature_flag_get_feature_flag" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'customer_name' is set
        if ('customer_name' not in params or
                params['customer_name'] is None):
            raise ValueError("Missing the required parameter `customer_name` when calling `feature_flag_get_feature_flag`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'customer_name' in params:
            path_params['customerName'] = params['customer_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/feature-flags/{customerName}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeGetFeatureFlagsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def feature_flag_get_limit_status(self, customer_name, limit, **kwargs):  # noqa: E501
        """GetLimitStatus  # noqa: E501

        Returns the status of a specified limit in this deployment's license.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.feature_flag_get_limit_status(customer_name, limit, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str customer_name: Name of the customer to query. (required)
        :param str limit: Specifies which limit to query. (required)
        :return: RimeGetLimitStatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.feature_flag_get_limit_status_with_http_info(customer_name, limit, **kwargs)  # noqa: E501
        else:
            (data) = self.feature_flag_get_limit_status_with_http_info(customer_name, limit, **kwargs)  # noqa: E501
            return data

    def feature_flag_get_limit_status_with_http_info(self, customer_name, limit, **kwargs):  # noqa: E501
        """GetLimitStatus  # noqa: E501

        Returns the status of a specified limit in this deployment's license.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.feature_flag_get_limit_status_with_http_info(customer_name, limit, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str customer_name: Name of the customer to query. (required)
        :param str limit: Specifies which limit to query. (required)
        :return: RimeGetLimitStatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['customer_name', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method feature_flag_get_limit_status" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'customer_name' is set
        if ('customer_name' not in params or
                params['customer_name'] is None):
            raise ValueError("Missing the required parameter `customer_name` when calling `feature_flag_get_limit_status`")  # noqa: E501
        # verify the required parameter 'limit' is set
        if ('limit' not in params or
                params['limit'] is None):
            raise ValueError("Missing the required parameter `limit` when calling `feature_flag_get_limit_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'customer_name' in params:
            path_params['customerName'] = params['customer_name']  # noqa: E501
        if 'limit' in params:
            path_params['limit'] = params['limit']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/feature-flags/{customerName}/limits/{limit}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeGetLimitStatusResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def feature_flag_list_enabled_features(self, customer_name, **kwargs):  # noqa: E501
        """ListEnabledFeatures  # noqa: E501

        Returns all features enabled in license for a customer.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.feature_flag_list_enabled_features(customer_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str customer_name: Name of the customer to query. (required)
        :return: RimeListEnabledFeaturesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.feature_flag_list_enabled_features_with_http_info(customer_name, **kwargs)  # noqa: E501
        else:
            (data) = self.feature_flag_list_enabled_features_with_http_info(customer_name, **kwargs)  # noqa: E501
            return data

    def feature_flag_list_enabled_features_with_http_info(self, customer_name, **kwargs):  # noqa: E501
        """ListEnabledFeatures  # noqa: E501

        Returns all features enabled in license for a customer.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.feature_flag_list_enabled_features_with_http_info(customer_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str customer_name: Name of the customer to query. (required)
        :return: RimeListEnabledFeaturesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['customer_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method feature_flag_list_enabled_features" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'customer_name' is set
        if ('customer_name' not in params or
                params['customer_name'] is None):
            raise ValueError("Missing the required parameter `customer_name` when calling `feature_flag_list_enabled_features`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'customer_name' in params:
            path_params['customerName'] = params['customer_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/feature-flags/{customerName}/features', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeListEnabledFeaturesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def feature_flag_upsert_feature_flag(self, body, customer_name, **kwargs):  # noqa: E501
        """UpsertFeatureFlag  # noqa: E501

        Update a feature JWT token with the customer name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.feature_flag_upsert_feature_flag(body, customer_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param FeatureflagsCustomerNameBody body: (required)
        :param str customer_name: Name of the customer to query. (required)
        :return: RimeUpsertFeatureFlagsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.feature_flag_upsert_feature_flag_with_http_info(body, customer_name, **kwargs)  # noqa: E501
        else:
            (data) = self.feature_flag_upsert_feature_flag_with_http_info(body, customer_name, **kwargs)  # noqa: E501
            return data

    def feature_flag_upsert_feature_flag_with_http_info(self, body, customer_name, **kwargs):  # noqa: E501
        """UpsertFeatureFlag  # noqa: E501

        Update a feature JWT token with the customer name.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.feature_flag_upsert_feature_flag_with_http_info(body, customer_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param FeatureflagsCustomerNameBody body: (required)
        :param str customer_name: Name of the customer to query. (required)
        :return: RimeUpsertFeatureFlagsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'customer_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method feature_flag_upsert_feature_flag" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `feature_flag_upsert_feature_flag`")  # noqa: E501
        # verify the required parameter 'customer_name' is set
        if ('customer_name' not in params or
                params['customer_name'] is None):
            raise ValueError("Missing the required parameter `customer_name` when calling `feature_flag_upsert_feature_flag`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'customer_name' in params:
            path_params['customerName'] = params['customer_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1/feature-flags/{customerName}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeUpsertFeatureFlagsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from rime_sdk.swagger.swagger_client.api_client import ApiClient


class FileScanningApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def file_scanning_delete_file_scan_result(self, file_scan_id_uuid, **kwargs):  # noqa: E501
        """DeleteFileScanResult  # noqa: E501

        Deletes a File Scan result by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.file_scanning_delete_file_scan_result(file_scan_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_scan_id_uuid: Unique object ID. (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.file_scanning_delete_file_scan_result_with_http_info(file_scan_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.file_scanning_delete_file_scan_result_with_http_info(file_scan_id_uuid, **kwargs)  # noqa: E501
            return data

    def file_scanning_delete_file_scan_result_with_http_info(self, file_scan_id_uuid, **kwargs):  # noqa: E501
        """DeleteFileScanResult  # noqa: E501

        Deletes a File Scan result by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.file_scanning_delete_file_scan_result_with_http_info(file_scan_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_scan_id_uuid: Unique object ID. (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['file_scan_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method file_scanning_delete_file_scan_result" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'file_scan_id_uuid' is set
        if ('file_scan_id_uuid' not in params or
                params['file_scan_id_uuid'] is None):
            raise ValueError("Missing the required parameter `file_scan_id_uuid` when calling `file_scanning_delete_file_scan_result`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'file_scan_id_uuid' in params:
            path_params['fileScanId.uuid'] = params['file_scan_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/file-scan-results/{fileScanId.uuid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def file_scanning_get_file_scan_result(self, file_scan_id_uuid, **kwargs):  # noqa: E501
        """GetFileScanResult  # noqa: E501

        Returns a File Scan result by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.file_scanning_get_file_scan_result(file_scan_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_scan_id_uuid: Unique object ID. (required)
        :return: RimeGetFileScanResultResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.file_scanning_get_file_scan_result_with_http_info(file_scan_id_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.file_scanning_get_file_scan_result_with_http_info(file_scan_id_uuid, **kwargs)  # noqa: E501
            return data

    def file_scanning_get_file_scan_result_with_http_info(self, file_scan_id_uuid, **kwargs):  # noqa: E501
        """GetFileScanResult  # noqa: E501

        Returns a File Scan result by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.file_scanning_get_file_scan_result_with_http_info(file_scan_id_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_scan_id_uuid: Unique object ID. (required)
        :return: RimeGetFileScanResultResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['file_scan_id_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method file_scanning_get_file_scan_result" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'file_scan_id_uuid' is set
        if ('file_scan_id_uuid' not in params or
                params['file_scan_id_uuid'] is None):
            raise ValueError("Missing the required parameter `file_scan_id_uuid` when calling `file_scanning_get_file_scan_result`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'file_scan_id_uuid' in params:
            path_params['fileScanId.uuid'] = params['file_scan_id_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/file-scan-results/{fileScanId.uuid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeGetFileScanResultResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def file_scanning_list_file_scan_results(self, **kwargs):  # noqa: E501
        """ListFileScanResults  # noqa: E501

        Returns a paginated list of all File Scan results for the project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.file_scanning_list_file_scan_results(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str first_page_query_project_id_uuid: Unique object ID.
        :param str first_page_query_model_id_uuid: Unique object ID.
        :param str page_token: Specifies a page of the list returned by a ListFileScan query beyond the first page.
        :param str page_size: Defines the maximum number of results on a given page. API call pagination navigates through the entire set of results in groups of the specified page size.
        :return: RimeListFileScanResultsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.file_scanning_list_file_scan_results_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.file_scanning_list_file_scan_results_with_http_info(**kwargs)  # noqa: E501
            return data

    def file_scanning_list_file_scan_results_with_http_info(self, **kwargs):  # noqa: E501
        """ListFileScanResults  # noqa: E501

        Returns a paginated list of all File Scan results for the project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.file_scanning_list_file_scan_results_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str first_page_query_project_id_uuid: Unique object ID.
        :param str first_page_query_model_id_uuid: Unique object ID.
        :param str page_token: Specifies a page of the list returned by a ListFileScan query beyond the first page.
        :param str page_size: Defines the maximum number of results on a given page. API call pagination navigates through the entire set of results in groups of the specified page size.
        :return: RimeListFileScanResultsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['first_page_query_project_id_uuid', 'first_page_query_model_id_uuid', 'page_token', 'page_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method file_scanning_list_file_scan_results" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'first_page_query_project_id_uuid' in params:
            query_params.append(('firstPageQuery.projectId.uuid', params['first_page_query_project_id_uuid']))  # noqa: E501
        if 'first_page_query_model_id_uuid' in params:
            query_params.append(('firstPageQuery.modelId.uuid', params['first_page_query_model_id_uuid']))  # noqa: E501
        if 'page_token' in params:
            query_params.append(('pageToken', params['page_token']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Firewall-Api-Key', 'X-Firewall-Auth-Token', 'rime-api-key']  # noqa: E501

        return self.api_client.call_api(
            '/v1-beta/file-scan-results', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RimeListFileScanResultsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RegistryPredictionParams(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'pred_col': 'str',
        'timestamp_col': 'str',
        'experimental_fields': 'dict(str, object)'
    }

    attribute_map = {
        'pred_col': 'predCol',
        'timestamp_col': 'timestampCol',
        'experimental_fields': 'experimentalFields'
    }

    def __init__(self, pred_col=None, timestamp_col=None, experimental_fields=None):  # noqa: E501
        """RegistryPredictionParams - a model defined in Swagger"""  # noqa: E501
        self._pred_col = None
        self._timestamp_col = None
        self._experimental_fields = None
        self.discriminator = None
        if pred_col is not None:
            self.pred_col = pred_col
        if timestamp_col is not None:
            self.timestamp_col = timestamp_col
        if experimental_fields is not None:
            self.experimental_fields = experimental_fields

    @property
    def pred_col(self):
        """Gets the pred_col of this RegistryPredictionParams.  # noqa: E501

        Column used for predictions.  # noqa: E501

        :return: The pred_col of this RegistryPredictionParams.  # noqa: E501
        :rtype: str
        """
        return self._pred_col

    @pred_col.setter
    def pred_col(self, pred_col):
        """Sets the pred_col of this RegistryPredictionParams.

        Column used for predictions.  # noqa: E501

        :param pred_col: The pred_col of this RegistryPredictionParams.  # noqa: E501
        :type: str
        """

        self._pred_col = pred_col

    @property
    def timestamp_col(self):
        """Gets the timestamp_col of this RegistryPredictionParams.  # noqa: E501

        Column used for CT timestamp.  # noqa: E501

        :return: The timestamp_col of this RegistryPredictionParams.  # noqa: E501
        :rtype: str
        """
        return self._timestamp_col

    @timestamp_col.setter
    def timestamp_col(self, timestamp_col):
        """Sets the timestamp_col of this RegistryPredictionParams.

        Column used for CT timestamp.  # noqa: E501

        :param timestamp_col: The timestamp_col of this RegistryPredictionParams.  # noqa: E501
        :type: str
        """

        self._timestamp_col = timestamp_col

    @property
    def experimental_fields(self):
        """Gets the experimental_fields of this RegistryPredictionParams.  # noqa: E501

        Fields that enable experimental functionality.  WARNING: these fields are experimental; ie, their functionality may not be reliable or backwards-compatible. Do not use these fields in production.  # noqa: E501

        :return: The experimental_fields of this RegistryPredictionParams.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._experimental_fields

    @experimental_fields.setter
    def experimental_fields(self, experimental_fields):
        """Sets the experimental_fields of this RegistryPredictionParams.

        Fields that enable experimental functionality.  WARNING: these fields are experimental; ie, their functionality may not be reliable or backwards-compatible. Do not use these fields in production.  # noqa: E501

        :param experimental_fields: The experimental_fields of this RegistryPredictionParams.  # noqa: E501
        :type: dict(str, object)
        """

        self._experimental_fields = experimental_fields

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RegistryPredictionParams, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RegistryPredictionParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SchemafilescanningFileSecurityReport(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'filename': 'str',
        'path': 'str',
        'size': 'str',
        'sha256': 'str',
        'creation_time': 'datetime',
        'last_modified_time': 'datetime',
        'dependencies': 'list[str]',
        'unexpected_dependencies': 'list[str]',
        'unsafe_dependencies': 'list[str]'
    }

    attribute_map = {
        'filename': 'filename',
        'path': 'path',
        'size': 'size',
        'sha256': 'sha256',
        'creation_time': 'creationTime',
        'last_modified_time': 'lastModifiedTime',
        'dependencies': 'dependencies',
        'unexpected_dependencies': 'unexpectedDependencies',
        'unsafe_dependencies': 'unsafeDependencies'
    }

    def __init__(self, filename=None, path=None, size=None, sha256=None, creation_time=None, last_modified_time=None, dependencies=None, unexpected_dependencies=None, unsafe_dependencies=None):  # noqa: E501
        """SchemafilescanningFileSecurityReport - a model defined in Swagger"""  # noqa: E501
        self._filename = None
        self._path = None
        self._size = None
        self._sha256 = None
        self._creation_time = None
        self._last_modified_time = None
        self._dependencies = None
        self._unexpected_dependencies = None
        self._unsafe_dependencies = None
        self.discriminator = None
        self.filename = filename
        if path is not None:
            self.path = path
        if size is not None:
            self.size = size
        if sha256 is not None:
            self.sha256 = sha256
        if creation_time is not None:
            self.creation_time = creation_time
        if last_modified_time is not None:
            self.last_modified_time = last_modified_time
        if dependencies is not None:
            self.dependencies = dependencies
        if unexpected_dependencies is not None:
            self.unexpected_dependencies = unexpected_dependencies
        if unsafe_dependencies is not None:
            self.unsafe_dependencies = unsafe_dependencies

    @property
    def filename(self):
        """Gets the filename of this SchemafilescanningFileSecurityReport.  # noqa: E501

        The name of the file that was scanned.  # noqa: E501

        :return: The filename of this SchemafilescanningFileSecurityReport.  # noqa: E501
        :rtype: str
        """
        return self._filename

    @filename.setter
    def filename(self, filename):
        """Sets the filename of this SchemafilescanningFileSecurityReport.

        The name of the file that was scanned.  # noqa: E501

        :param filename: The filename of this SchemafilescanningFileSecurityReport.  # noqa: E501
        :type: str
        """
        if filename is None:
            raise ValueError("Invalid value for `filename`, must not be `None`")  # noqa: E501

        self._filename = filename

    @property
    def path(self):
        """Gets the path of this SchemafilescanningFileSecurityReport.  # noqa: E501


        :return: The path of this SchemafilescanningFileSecurityReport.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this SchemafilescanningFileSecurityReport.


        :param path: The path of this SchemafilescanningFileSecurityReport.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def size(self):
        """Gets the size of this SchemafilescanningFileSecurityReport.  # noqa: E501

        The size of the file in bytes.  # noqa: E501

        :return: The size of this SchemafilescanningFileSecurityReport.  # noqa: E501
        :rtype: str
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this SchemafilescanningFileSecurityReport.

        The size of the file in bytes.  # noqa: E501

        :param size: The size of this SchemafilescanningFileSecurityReport.  # noqa: E501
        :type: str
        """

        self._size = size

    @property
    def sha256(self):
        """Gets the sha256 of this SchemafilescanningFileSecurityReport.  # noqa: E501


        :return: The sha256 of this SchemafilescanningFileSecurityReport.  # noqa: E501
        :rtype: str
        """
        return self._sha256

    @sha256.setter
    def sha256(self, sha256):
        """Sets the sha256 of this SchemafilescanningFileSecurityReport.


        :param sha256: The sha256 of this SchemafilescanningFileSecurityReport.  # noqa: E501
        :type: str
        """

        self._sha256 = sha256

    @property
    def creation_time(self):
        """Gets the creation_time of this SchemafilescanningFileSecurityReport.  # noqa: E501

        The time when the file was created.  # noqa: E501

        :return: The creation_time of this SchemafilescanningFileSecurityReport.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """Sets the creation_time of this SchemafilescanningFileSecurityReport.

        The time when the file was created.  # noqa: E501

        :param creation_time: The creation_time of this SchemafilescanningFileSecurityReport.  # noqa: E501
        :type: datetime
        """

        self._creation_time = creation_time

    @property
    def last_modified_time(self):
        """Gets the last_modified_time of this SchemafilescanningFileSecurityReport.  # noqa: E501

        The time when the file was last modified.  # noqa: E501

        :return: The last_modified_time of this SchemafilescanningFileSecurityReport.  # noqa: E501
        :rtype: datetime
        """
        return self._last_modified_time

    @last_modified_time.setter
    def last_modified_time(self, last_modified_time):
        """Sets the last_modified_time of this SchemafilescanningFileSecurityReport.

        The time when the file was last modified.  # noqa: E501

        :param last_modified_time: The last_modified_time of this SchemafilescanningFileSecurityReport.  # noqa: E501
        :type: datetime
        """

        self._last_modified_time = last_modified_time

    @property
    def dependencies(self):
        """Gets the dependencies of this SchemafilescanningFileSecurityReport.  # noqa: E501

        The list of all dependencies in the file.  # noqa: E501

        :return: The dependencies of this SchemafilescanningFileSecurityReport.  # noqa: E501
        :rtype: list[str]
        """
        return self._dependencies

    @dependencies.setter
    def dependencies(self, dependencies):
        """Sets the dependencies of this SchemafilescanningFileSecurityReport.

        The list of all dependencies in the file.  # noqa: E501

        :param dependencies: The dependencies of this SchemafilescanningFileSecurityReport.  # noqa: E501
        :type: list[str]
        """

        self._dependencies = dependencies

    @property
    def unexpected_dependencies(self):
        """Gets the unexpected_dependencies of this SchemafilescanningFileSecurityReport.  # noqa: E501

        The list of unexpected dependencies.  # noqa: E501

        :return: The unexpected_dependencies of this SchemafilescanningFileSecurityReport.  # noqa: E501
        :rtype: list[str]
        """
        return self._unexpected_dependencies

    @unexpected_dependencies.setter
    def unexpected_dependencies(self, unexpected_dependencies):
        """Sets the unexpected_dependencies of this SchemafilescanningFileSecurityReport.

        The list of unexpected dependencies.  # noqa: E501

        :param unexpected_dependencies: The unexpected_dependencies of this SchemafilescanningFileSecurityReport.  # noqa: E501
        :type: list[str]
        """

        self._unexpected_dependencies = unexpected_dependencies

    @property
    def unsafe_dependencies(self):
        """Gets the unsafe_dependencies of this SchemafilescanningFileSecurityReport.  # noqa: E501

        The list of unsafe dependencies.  # noqa: E501

        :return: The unsafe_dependencies of this SchemafilescanningFileSecurityReport.  # noqa: E501
        :rtype: list[str]
        """
        return self._unsafe_dependencies

    @unsafe_dependencies.setter
    def unsafe_dependencies(self, unsafe_dependencies):
        """Sets the unsafe_dependencies of this SchemafilescanningFileSecurityReport.

        The list of unsafe dependencies.  # noqa: E501

        :param unsafe_dependencies: The unsafe_dependencies of this SchemafilescanningFileSecurityReport.  # noqa: E501
        :type: list[str]
        """

        self._unsafe_dependencies = unsafe_dependencies

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SchemafilescanningFileSecurityReport, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SchemafilescanningFileSecurityReport):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RimeUpdateBuildInfoRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'built_successfully': 'bool',
        'pip_libraries': 'list[ManagedImagePipLibrary]'
    }

    attribute_map = {
        'name': 'name',
        'built_successfully': 'builtSuccessfully',
        'pip_libraries': 'pipLibraries'
    }

    def __init__(self, name=None, built_successfully=None, pip_libraries=None):  # noqa: E501
        """RimeUpdateBuildInfoRequest - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._built_successfully = None
        self._pip_libraries = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if built_successfully is not None:
            self.built_successfully = built_successfully
        if pip_libraries is not None:
            self.pip_libraries = pip_libraries

    @property
    def name(self):
        """Gets the name of this RimeUpdateBuildInfoRequest.  # noqa: E501

        This name must match the regexp described in managed_image.proto for `ManagedImage.name`.  # noqa: E501

        :return: The name of this RimeUpdateBuildInfoRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RimeUpdateBuildInfoRequest.

        This name must match the regexp described in managed_image.proto for `ManagedImage.name`.  # noqa: E501

        :param name: The name of this RimeUpdateBuildInfoRequest.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def built_successfully(self):
        """Gets the built_successfully of this RimeUpdateBuildInfoRequest.  # noqa: E501


        :return: The built_successfully of this RimeUpdateBuildInfoRequest.  # noqa: E501
        :rtype: bool
        """
        return self._built_successfully

    @built_successfully.setter
    def built_successfully(self, built_successfully):
        """Sets the built_successfully of this RimeUpdateBuildInfoRequest.


        :param built_successfully: The built_successfully of this RimeUpdateBuildInfoRequest.  # noqa: E501
        :type: bool
        """

        self._built_successfully = built_successfully

    @property
    def pip_libraries(self):
        """Gets the pip_libraries of this RimeUpdateBuildInfoRequest.  # noqa: E501


        :return: The pip_libraries of this RimeUpdateBuildInfoRequest.  # noqa: E501
        :rtype: list[ManagedImagePipLibrary]
        """
        return self._pip_libraries

    @pip_libraries.setter
    def pip_libraries(self, pip_libraries):
        """Sets the pip_libraries of this RimeUpdateBuildInfoRequest.


        :param pip_libraries: The pip_libraries of this RimeUpdateBuildInfoRequest.  # noqa: E501
        :type: list[ManagedImagePipLibrary]
        """

        self._pip_libraries = pip_libraries

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RimeUpdateBuildInfoRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RimeUpdateBuildInfoRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RimeGetModelSecurityReportResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'repo_id': 'str',
        'repo_type': 'RimeRepoType',
        'description': 'str',
        'repo_metadata': 'RimeRepoMetadata',
        'file_scan_result': 'RimeFileScanResult'
    }

    attribute_map = {
        'repo_id': 'repoId',
        'repo_type': 'repoType',
        'description': 'description',
        'repo_metadata': 'repoMetadata',
        'file_scan_result': 'fileScanResult'
    }

    def __init__(self, repo_id=None, repo_type=None, description=None, repo_metadata=None, file_scan_result=None):  # noqa: E501
        """RimeGetModelSecurityReportResponse - a model defined in Swagger"""  # noqa: E501
        self._repo_id = None
        self._repo_type = None
        self._description = None
        self._repo_metadata = None
        self._file_scan_result = None
        self.discriminator = None
        if repo_id is not None:
            self.repo_id = repo_id
        if repo_type is not None:
            self.repo_type = repo_type
        if description is not None:
            self.description = description
        if repo_metadata is not None:
            self.repo_metadata = repo_metadata
        if file_scan_result is not None:
            self.file_scan_result = file_scan_result

    @property
    def repo_id(self):
        """Gets the repo_id of this RimeGetModelSecurityReportResponse.  # noqa: E501

        The ID of the model repository on Hugging Face.  # noqa: E501

        :return: The repo_id of this RimeGetModelSecurityReportResponse.  # noqa: E501
        :rtype: str
        """
        return self._repo_id

    @repo_id.setter
    def repo_id(self, repo_id):
        """Sets the repo_id of this RimeGetModelSecurityReportResponse.

        The ID of the model repository on Hugging Face.  # noqa: E501

        :param repo_id: The repo_id of this RimeGetModelSecurityReportResponse.  # noqa: E501
        :type: str
        """

        self._repo_id = repo_id

    @property
    def repo_type(self):
        """Gets the repo_type of this RimeGetModelSecurityReportResponse.  # noqa: E501


        :return: The repo_type of this RimeGetModelSecurityReportResponse.  # noqa: E501
        :rtype: RimeRepoType
        """
        return self._repo_type

    @repo_type.setter
    def repo_type(self, repo_type):
        """Sets the repo_type of this RimeGetModelSecurityReportResponse.


        :param repo_type: The repo_type of this RimeGetModelSecurityReportResponse.  # noqa: E501
        :type: RimeRepoType
        """

        self._repo_type = repo_type

    @property
    def description(self):
        """Gets the description of this RimeGetModelSecurityReportResponse.  # noqa: E501

        Description of the availability of the security report such as 'Scan completed' or 'Scan in progress. Please check back later for results'.  # noqa: E501

        :return: The description of this RimeGetModelSecurityReportResponse.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this RimeGetModelSecurityReportResponse.

        Description of the availability of the security report such as 'Scan completed' or 'Scan in progress. Please check back later for results'.  # noqa: E501

        :param description: The description of this RimeGetModelSecurityReportResponse.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def repo_metadata(self):
        """Gets the repo_metadata of this RimeGetModelSecurityReportResponse.  # noqa: E501


        :return: The repo_metadata of this RimeGetModelSecurityReportResponse.  # noqa: E501
        :rtype: RimeRepoMetadata
        """
        return self._repo_metadata

    @repo_metadata.setter
    def repo_metadata(self, repo_metadata):
        """Sets the repo_metadata of this RimeGetModelSecurityReportResponse.


        :param repo_metadata: The repo_metadata of this RimeGetModelSecurityReportResponse.  # noqa: E501
        :type: RimeRepoMetadata
        """

        self._repo_metadata = repo_metadata

    @property
    def file_scan_result(self):
        """Gets the file_scan_result of this RimeGetModelSecurityReportResponse.  # noqa: E501


        :return: The file_scan_result of this RimeGetModelSecurityReportResponse.  # noqa: E501
        :rtype: RimeFileScanResult
        """
        return self._file_scan_result

    @file_scan_result.setter
    def file_scan_result(self, file_scan_result):
        """Sets the file_scan_result of this RimeGetModelSecurityReportResponse.


        :param file_scan_result: The file_scan_result of this RimeGetModelSecurityReportResponse.  # noqa: E501
        :type: RimeFileScanResult
        """

        self._file_scan_result = file_scan_result

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RimeGetModelSecurityReportResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RimeGetModelSecurityReportResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class FirewallScheduledCTInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'eval_data_integration_id': 'RimeUUID',
        'eval_data_info': 'RegistryDataInfo',
        'eval_pred_integration_id': 'RimeUUID',
        'eval_pred_info': 'RegistryPredInfo',
        'last_ct_scheduled': 'datetime',
        'activated_time': 'datetime',
        'disable_scheduled_ct': 'bool'
    }

    attribute_map = {
        'eval_data_integration_id': 'evalDataIntegrationId',
        'eval_data_info': 'evalDataInfo',
        'eval_pred_integration_id': 'evalPredIntegrationId',
        'eval_pred_info': 'evalPredInfo',
        'last_ct_scheduled': 'lastCtScheduled',
        'activated_time': 'activatedTime',
        'disable_scheduled_ct': 'disableScheduledCt'
    }

    def __init__(self, eval_data_integration_id=None, eval_data_info=None, eval_pred_integration_id=None, eval_pred_info=None, last_ct_scheduled=None, activated_time=None, disable_scheduled_ct=None):  # noqa: E501
        """FirewallScheduledCTInfo - a model defined in Swagger"""  # noqa: E501
        self._eval_data_integration_id = None
        self._eval_data_info = None
        self._eval_pred_integration_id = None
        self._eval_pred_info = None
        self._last_ct_scheduled = None
        self._activated_time = None
        self._disable_scheduled_ct = None
        self.discriminator = None
        if eval_data_integration_id is not None:
            self.eval_data_integration_id = eval_data_integration_id
        if eval_data_info is not None:
            self.eval_data_info = eval_data_info
        if eval_pred_integration_id is not None:
            self.eval_pred_integration_id = eval_pred_integration_id
        if eval_pred_info is not None:
            self.eval_pred_info = eval_pred_info
        if last_ct_scheduled is not None:
            self.last_ct_scheduled = last_ct_scheduled
        if activated_time is not None:
            self.activated_time = activated_time
        if disable_scheduled_ct is not None:
            self.disable_scheduled_ct = disable_scheduled_ct

    @property
    def eval_data_integration_id(self):
        """Gets the eval_data_integration_id of this FirewallScheduledCTInfo.  # noqa: E501


        :return: The eval_data_integration_id of this FirewallScheduledCTInfo.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._eval_data_integration_id

    @eval_data_integration_id.setter
    def eval_data_integration_id(self, eval_data_integration_id):
        """Sets the eval_data_integration_id of this FirewallScheduledCTInfo.


        :param eval_data_integration_id: The eval_data_integration_id of this FirewallScheduledCTInfo.  # noqa: E501
        :type: RimeUUID
        """

        self._eval_data_integration_id = eval_data_integration_id

    @property
    def eval_data_info(self):
        """Gets the eval_data_info of this FirewallScheduledCTInfo.  # noqa: E501


        :return: The eval_data_info of this FirewallScheduledCTInfo.  # noqa: E501
        :rtype: RegistryDataInfo
        """
        return self._eval_data_info

    @eval_data_info.setter
    def eval_data_info(self, eval_data_info):
        """Sets the eval_data_info of this FirewallScheduledCTInfo.


        :param eval_data_info: The eval_data_info of this FirewallScheduledCTInfo.  # noqa: E501
        :type: RegistryDataInfo
        """

        self._eval_data_info = eval_data_info

    @property
    def eval_pred_integration_id(self):
        """Gets the eval_pred_integration_id of this FirewallScheduledCTInfo.  # noqa: E501


        :return: The eval_pred_integration_id of this FirewallScheduledCTInfo.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._eval_pred_integration_id

    @eval_pred_integration_id.setter
    def eval_pred_integration_id(self, eval_pred_integration_id):
        """Sets the eval_pred_integration_id of this FirewallScheduledCTInfo.


        :param eval_pred_integration_id: The eval_pred_integration_id of this FirewallScheduledCTInfo.  # noqa: E501
        :type: RimeUUID
        """

        self._eval_pred_integration_id = eval_pred_integration_id

    @property
    def eval_pred_info(self):
        """Gets the eval_pred_info of this FirewallScheduledCTInfo.  # noqa: E501


        :return: The eval_pred_info of this FirewallScheduledCTInfo.  # noqa: E501
        :rtype: RegistryPredInfo
        """
        return self._eval_pred_info

    @eval_pred_info.setter
    def eval_pred_info(self, eval_pred_info):
        """Sets the eval_pred_info of this FirewallScheduledCTInfo.


        :param eval_pred_info: The eval_pred_info of this FirewallScheduledCTInfo.  # noqa: E501
        :type: RegistryPredInfo
        """

        self._eval_pred_info = eval_pred_info

    @property
    def last_ct_scheduled(self):
        """Gets the last_ct_scheduled of this FirewallScheduledCTInfo.  # noqa: E501

        Specifies a timestamp based on the end time of the window for each run. The scheduler uses this timestamp to determine job start times and the time bin to use.  # noqa: E501

        :return: The last_ct_scheduled of this FirewallScheduledCTInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._last_ct_scheduled

    @last_ct_scheduled.setter
    def last_ct_scheduled(self, last_ct_scheduled):
        """Sets the last_ct_scheduled of this FirewallScheduledCTInfo.

        Specifies a timestamp based on the end time of the window for each run. The scheduler uses this timestamp to determine job start times and the time bin to use.  # noqa: E501

        :param last_ct_scheduled: The last_ct_scheduled of this FirewallScheduledCTInfo.  # noqa: E501
        :type: datetime
        """

        self._last_ct_scheduled = last_ct_scheduled

    @property
    def activated_time(self):
        """Gets the activated_time of this FirewallScheduledCTInfo.  # noqa: E501

        When the AI Firewall has no bins, this value is used as the start time. Otherwise, the end time of the last bin in the AI Firewall is used as the AI Firewall start time.  # noqa: E501

        :return: The activated_time of this FirewallScheduledCTInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._activated_time

    @activated_time.setter
    def activated_time(self, activated_time):
        """Sets the activated_time of this FirewallScheduledCTInfo.

        When the AI Firewall has no bins, this value is used as the start time. Otherwise, the end time of the last bin in the AI Firewall is used as the AI Firewall start time.  # noqa: E501

        :param activated_time: The activated_time of this FirewallScheduledCTInfo.  # noqa: E501
        :type: datetime
        """

        self._activated_time = activated_time

    @property
    def disable_scheduled_ct(self):
        """Gets the disable_scheduled_ct of this FirewallScheduledCTInfo.  # noqa: E501

        Option for disabling scheduled CT - this should be false by default. This enables users to suspend a scheduled CT while preserving existing settings.  # noqa: E501

        :return: The disable_scheduled_ct of this FirewallScheduledCTInfo.  # noqa: E501
        :rtype: bool
        """
        return self._disable_scheduled_ct

    @disable_scheduled_ct.setter
    def disable_scheduled_ct(self, disable_scheduled_ct):
        """Sets the disable_scheduled_ct of this FirewallScheduledCTInfo.

        Option for disabling scheduled CT - this should be false by default. This enables users to suspend a scheduled CT while preserving existing settings.  # noqa: E501

        :param disable_scheduled_ct: The disable_scheduled_ct of this FirewallScheduledCTInfo.  # noqa: E501
        :type: bool
        """

        self._disable_scheduled_ct = disable_scheduled_ct

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FirewallScheduledCTInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FirewallScheduledCTInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
